@@ -11,6 +11,7 @@ from pyiron_base.generic.util import static_isinstance
 import tarfile
 import stat
 import shutil
+from typing import Union, Dict
 
 __author__ = "Jan Janssen"
 __copyright__ = (
@@ -113,12 +114,39 @@ def _get_project_for_copy(job, project, new_job_name):
     return file_project, hdf5_project
 
 
+_special_symbol_replacements = {
+    '.': 'd',
+    '-': 'm',
+    '+': 'p',
+    ',': 'c',
+    ' ': '_',
+}
+
+
+def _get_safe_job_name(name: str, ndigits: Union[int, None] = 8, special_symbols: Union[Dict, None] = None):
+    d_special_symbols = _special_symbol_replacements.copy()
+    if special_symbols is not None:
+        d_special_symbols.update(special_symbols)
+    def round_(value, ndigits=ndigits):
+        if isinstance(value, float) and ndigits is not None:
+            return round(value, ndigits=ndigits)
+        return value
+    if not isinstance(name, str):
+        name_rounded = [round_(nn) for nn in name]
+        job_name = '_'.join([str(nn) for nn in name_rounded])
+    else:
+        job_name = name
+    for k, v in d_special_symbols.items():
+        job_name = job_name.replace(k, v)
+    _is_valid_job_name(job_name=job_name)
+    return job_name
+
+
 def _rename_job(job, new_job_name):
     """
 
     """
-    new_job_name = new_job_name.replace(".", "_")
-    _is_valid_job_name(job_name=new_job_name)
+    new_job_name = _get_safe_job_name(new_job_name)
     child_ids = job.child_ids
     if child_ids:
         for child_id in child_ids:
